certbot-dns-internal
====================

Buddy internal DNS Authenticator plugin for Certbot

This plugin automates the process of completing a ``dns-01`` challenge by
creating, and subsequently removing, TXT records using the Buddy internal API.